/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.state;

import de.intevation.gnv.artifacts.GNVArtifactBase;

import org.apache.log4j.Logger;

import org.w3c.dom.Node;

/**
 * This factory should be used to create new state objects with help of a
 * configuration segment.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class StateFactory {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(GNVArtifactBase.class);

    private static StateFactory instance = null;

    /**
     * Constructor
     */
    public StateFactory() {
        super();
    }

    /**
     * Return the instance of this class.
     */
    public static StateFactory getInstance() {
        if (instance == null) {
            instance = new StateFactory();
        }
        return instance;
    }

    /**
     * This method creates a new state with help of the information in <i>
     * configuration</i> and calls its setup method after creation.
     *
     * @return the new state.
     */
    public State createState(Node configuration) {
        log.debug("StateFactory.createState");
        State state = null;
        try {
            String classname = ((org.w3c.dom.Element)configuration).getAttribute("state");
            state = (State) (Class.forName(classname).newInstance());
            state.setup(configuration);
        } catch (InstantiationException e) {
            log.error(e, e);
        } catch (IllegalAccessException e) {
            log.error(e, e);
        } catch (ClassNotFoundException e) {
            log.error(e, e);
        }
        return state;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
